@@ -1,30 +1,17 @@
 #ifndef __CLUTTER_STAGE_WINDOW_H__
 #define __CLUTTER_STAGE_WINDOW_H__
 
-#include <clutter/clutter-actor.h>
 #include <cogl/cogl.h>
-#include <cairo.h>
-
-/* XXX: Some of the private parts in this header expect the
- * CoglFramebuffer typedef from Cogl, but its possible for this header
- * to be included without the experimental Cogl api having been
- * selected by defining COGL_ENABLE_EXPERIMENTAL_API or
- * COGL_ENABLE_EXPERIMENTAL_2_0_API.
- *
- * We declare a  place holder type ourselves in this case...
- */
-#ifndef COGL_ENABLE_EXPERIMENTAL_API
-typedef struct _CoglFramebuffer CoglFramebuffer;
-#endif
+#include <clutter/clutter-types.h>
 
 G_BEGIN_DECLS
 
-#define CLUTTER_TYPE_STAGE_WINDOW               (clutter_stage_window_get_type ())
+#define CLUTTER_TYPE_STAGE_WINDOW               (_clutter_stage_window_get_type ())
 #define CLUTTER_STAGE_WINDOW(obj)               (G_TYPE_CHECK_INSTANCE_CAST ((obj), CLUTTER_TYPE_STAGE_WINDOW, ClutterStageWindow))
 #define CLUTTER_IS_STAGE_WINDOW(obj)            (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CLUTTER_TYPE_STAGE_WINDOW))
 #define CLUTTER_STAGE_WINDOW_GET_IFACE(obj)     (G_TYPE_INSTANCE_GET_INTERFACE ((obj), CLUTTER_TYPE_STAGE_WINDOW, ClutterStageWindowIface))
 
-/**
+/*
  * ClutterStageWindow: (skip)
  *
  * <structname>ClutterStageWindow</structname> is an opaque structure
@@ -35,7 +22,7 @@ G_BEGIN_DECLS
 typedef struct _ClutterStageWindow      ClutterStageWindow; /* dummy */
 typedef struct _ClutterStageWindowIface ClutterStageWindowIface;
 
-/**
+/*
  * ClutterStageWindowIface: (skip)
  *
  * The interface implemented by backends for stage windows
@@ -71,7 +58,10 @@ struct _ClutterStageWindowIface
   void              (* get_geometry)            (ClutterStageWindow *stage_window,
                                                  cairo_rectangle_int_t *geometry);
 
-  int               (* get_pending_swaps)       (ClutterStageWindow *stage_window);
+  void              (* schedule_update)         (ClutterStageWindow *stage_window,
+                                                 int                 sync_delay);
+  gint64            (* get_update_time)         (ClutterStageWindow *stage_window);
+  void              (* clear_update_time)       (ClutterStageWindow *stage_window);
 
   void              (* add_redraw_clip)         (ClutterStageWindow    *stage_window,
                                                  cairo_rectangle_int_t *stage_rectangle);
@@ -86,12 +76,17 @@ struct _ClutterStageWindowIface
 
   void              (* redraw)                  (ClutterStageWindow *stage_window);
 
+  void              (* dirty_back_buffer)       (ClutterStageWindow *stage_window);
+
+  void              (* get_dirty_pixel)         (ClutterStageWindow *stage_window,
+                                                 int *x, int *y);
+
   CoglFramebuffer  *(* get_active_framebuffer)  (ClutterStageWindow *stage_window);
 
   gboolean          (* can_clip_redraws)        (ClutterStageWindow *stage_window);
 };
 
-GType clutter_stage_window_get_type (void) G_GNUC_CONST;
+GType _clutter_stage_window_get_type (void) G_GNUC_CONST;
 
 ClutterActor *    _clutter_stage_window_get_wrapper        (ClutterStageWindow *window);
 
@@ -116,7 +111,10 @@ void              _clutter_stage_window_resize                  (ClutterStageWin
                                                                  gint                height);
 void              _clutter_stage_window_get_geometry            (ClutterStageWindow *window,
                                                                  cairo_rectangle_int_t *geometry);
-int               _clutter_stage_window_get_pending_swaps       (ClutterStageWindow *window);
+void              _clutter_stage_window_schedule_update         (ClutterStageWindow *window,
+                                                                 int                 sync_delay);
+gint64            _clutter_stage_window_get_update_time         (ClutterStageWindow *window);
+void              _clutter_stage_window_clear_update_time       (ClutterStageWindow *window);
 
 void              _clutter_stage_window_add_redraw_clip         (ClutterStageWindow    *window,
                                                                  cairo_rectangle_int_t *stage_clip);
@@ -130,6 +128,11 @@ void              _clutter_stage_window_set_accept_focus        (ClutterStageWin
 
 void              _clutter_stage_window_redraw                  (ClutterStageWindow *window);
 
+void              _clutter_stage_window_dirty_back_buffer       (ClutterStageWindow *window);
+
+void              _clutter_stage_window_get_dirty_pixel         (ClutterStageWindow *window,
+                                                                 int *x, int *y);
+
 CoglFramebuffer  *_clutter_stage_window_get_active_framebuffer  (ClutterStageWindow *window);
 
 gboolean          _clutter_stage_window_can_clip_redraws        (ClutterStageWindow *window);
